@@ -939,7 +939,7 @@ if (!strncmp(name, "GL_", 3)) {
 	i(GL_COLOR_TABLE_ALPHA_SIZE_EXT)
 	i(GL_COLOR_TABLE_LUMINANCE_SIZE_EXT)
 	i(GL_COLOR_TABLE_INTENSITY_SIZE_EXT)
-	i(GL_TEXTURE_INDEX_SIZE_EXT)
+	/* i(GL_TEXTURE_INDEX_SIZE_EXT) */
 	i(GL_COLOR_INDEX1_EXT)
 	i(GL_COLOR_INDEX2_EXT)
 	i(GL_COLOR_INDEX4_EXT)
